@@ -29,5 +29,6 @@ export default {
   "Unselect": "Unselect",
   "Configure layer": "Configure layer",
   "Properties: [{0}] {1}": "Properties: [{0}] {1}",
-  "Get Screenshot": "Get Screenshot"
+  "Get Screenshot": "Get Screenshot",
+  "Catalog": "Catalog"
 };
\ No newline at end of file
