@@ -7,14 +7,15 @@ import PanelLayerElements from './panel-layer-elements';
 export default function Sidebar({width, height, state}) {
   return (
     <aside
-      style={{backgroundColor: "#28292D", display:"block", overflow: "scroll", width, height}}
+      style={{backgroundColor: "#28292D", display: "block", overflow: "scroll", width, height}}
       onKeyDown={event => event.stopPropagation()}
       onKeyUp={event => event.stopPropagation()}
+      className="sidebar"
     >
-      <PanelLayerElements state={state}/>
-      <PanelPropertiesEditor state={state}/>
-      {/*<PanelGuides state={state}/>*/}
-      <PanelLayers state={state}/>
+      <div className="layer-elements"><PanelLayerElements state={state}/></div>
+      <div className="properties"><PanelPropertiesEditor state={state}/></div>
+      {/*<div className="guides"><PanelGuides state={state}/></div>*/}
+      <div className="layers"><PanelLayers state={state}/></div>
     </aside>
   );
 }
